==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_fields/USERGISMAPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour USERGISMAPID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="USERGISMAPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GISMAPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "USERGISMAPID_Type", propOrder = {
    "userid",
    "gismapid",
    "departmentid"
})
public class USERGISMAPID_Type {

    @XmlElement(name = "USERID", required = true)
    protected USERID_Type userid;
    @XmlElement(name = "GISMAPID", required = true)
    protected GISMAPID_Type gismapid;
    @XmlElement(name = "DEPARTMENTID")
    protected DEPARTMENTID_Type departmentid;

    /**
     * Obtient la valeur de la propriété userid.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUSERID() {
        return userid;
    }

    /**
     * Définit la valeur de la propriété userid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUSERID(USERID_Type value) {
        this.userid = value;
    }

    /**
     * Obtient la valeur de la propriété gismapid.
     * 
     * @return
     *     possible object is
     *     {@link GISMAPID_Type }
     *     
     */
    public GISMAPID_Type getGISMAPID() {
        return gismapid;
    }

    /**
     * Définit la valeur de la propriété gismapid.
     * 
     * @param value
     *     allowed object is
     *     {@link GISMAPID_Type }
     *     
     */
    public void setGISMAPID(GISMAPID_Type value) {
        this.gismapid = value;
    }

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/USERGISMAPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for USERGISMAPID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="USERGISMAPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GISMAPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "USERGISMAPID_Type", propOrder = {
    "userid",
    "gismapid",
    "departmentid"
})
public class USERGISMAPID_Type {

    @XmlElement(name = "USERID", required = true)
    protected USERID_Type userid;
    @XmlElement(name = "GISMAPID", required = true)
    protected GISMAPID_Type gismapid;
    @XmlElement(name = "DEPARTMENTID")
    protected DEPARTMENTID_Type departmentid;

    /**
     * Gets the value of the userid property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUSERID() {
        return userid;
    }

    /**
     * Sets the value of the userid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUSERID(USERID_Type value) {
        this.userid = value;
    }

    /**
     * Gets the value of the gismapid property.
     * 
     * @return
     *     possible object is
     *     {@link GISMAPID_Type }
     *     
     */
    public GISMAPID_Type getGISMAPID() {
        return gismapid;
    }

    /**
     * Sets the value of the gismapid property.
     * 
     * @param value
     *     allowed object is
     *     {@link GISMAPID_Type }
     *     
     */
    public void setGISMAPID(GISMAPID_Type value) {
        this.gismapid = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

}
